@@ -14,5 +14,5 @@ fn system(
 }
 
 fn main() {
-    system.system();
+    IntoSystem::into_system(system);
 }
